# GetMachineTypeResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**count_clusters** | **int** |  | 
**count_hosts** | **int** |  | 
**count_hosts_active** | **int** |  | 
**count_hosts_inactive** | **int** |  | 
**cpu_models** | **list[str]** |  | 
**data_center_id** | **str** |  | 
**gpu_models** | **list[str]** |  | 
**machine_type** | **str** |  | 
**max_gpu_price_hr** | [**Decimal**](Decimal.md) |  | 
**max_memory_gib_price_hr** | [**Decimal**](Decimal.md) |  | 
**max_vcpu_per_gpu** | **float** |  | 
**max_vcpu_per_memory_gib** | **float** |  | 
**max_vcpu_price_hr** | [**Decimal**](Decimal.md) |  | 
**min_gpu_price_hr** | [**Decimal**](Decimal.md) |  | 
**min_memory_gib_price_hr** | [**Decimal**](Decimal.md) |  | 
**min_vcpu_per_gpu** | **float** |  | 
**min_vcpu_per_memory_gib** | **float** |  | 
**min_vcpu_price_hr** | [**Decimal**](Decimal.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


